@@ -294,17 +294,24 @@ class MatrixWavedec(object):
 
         Args:
             input_signal (torch.Tensor): Batched input data [batch_size, time],
-                  should be of even length.
+                should be of even length. 1d inputs are interpreted as [time].
 
         Returns:
             List[torch.Tensor]: A list with the coefficients for each scale.
 
         Raises:
-            ValueError: If the decomposition level is not a positive integer.
+            ValueError: If the decomposition level is not a positive integer
+                or if the input signal has not the expected shape.
         """
-        if len(input_signal.shape) == 1:
+        if input_signal.dim() == 1:
             # assume time series
             input_signal = input_signal.unsqueeze(0)
+        elif input_signal.dim() != 2:
+            raise ValueError(
+                f"Invalid input tensor shape {input_signal.size()}. "
+                "The input signal is expected to be of the form "
+                "[batch_size, length]."
+            )
 
         if input_signal.shape[-1] % 2 != 0:
             # odd length input
@@ -339,7 +346,8 @@ class MatrixWavedec(object):
             lo, hi = torch.split(coefficients, coefficients.shape[0] // 2, dim=0)
             split_list.append(hi)
         split_list.append(lo)
-        return split_list[::-1]
+        # undo the transpose we used to handle the batch dimension.
+        return [s.T for s in split_list[::-1]]
 
 
 def construct_boundary_a(
@@ -551,7 +559,7 @@ class MatrixWaverec(object):
                 `MatrixWavedec` object.
         """
         level = len(coefficients) - 1
-        input_length = coefficients[-1].shape[0] * 2
+        input_length = coefficients[-1].shape[-1] * 2
 
         re_build = False
         if self.level != level or self.input_length != input_length:
@@ -565,6 +573,9 @@ class MatrixWaverec(object):
                 dtype=coefficients[-1].dtype,
             )
 
+        # transpose the coefficients to handle the batch dimension efficiently.
+        coefficients = [c.T for c in coefficients]
+
         lo = coefficients[0]
         for c_pos, hi in enumerate(coefficients[1:]):
             torch_device = None
@@ -604,14 +615,3 @@ class MatrixWaverec(object):
                     ), "padding error, please open an issue on github"
 
         return lo.T
-
-
-if __name__ == "__main__":
-    import pywt
-    import torch
-    import matplotlib.pyplot as plt
-
-    a = _construct_a(pywt.Wavelet("haar"), 20, torch.device("cpu"))
-    s = _construct_s(pywt.Wavelet("haar"), 20, torch.device("cpu"))
-    plt.spy(torch.sparse.mm(s, a).to_dense(), marker=".")
-    plt.show()
